@@ -411,7 +411,8 @@ g_io_modules_scan_all_in_directory (const char *dirname)
  * all gtypes) then you can use g_io_modules_scan_all_in_directory()
  * which allows delayed/lazy loading of modules.
  *
- * Returns: a list of #GIOModules loaded from the directory,
+ * Returns: (element-type GIOModule) (transfer full): a list of #GIOModules loaded
+ *      from the directory,
  *      All the modules are loaded into memory, if you want to
  *      unload them (enabling on-demand loading) you must call
  *      g_type_module_unuse() on all the modules. Free the list
@@ -522,11 +523,6 @@ _g_io_modules_ensure_extension_points_registered (void)
     {
       registered_extensions = TRUE;
       
-#ifdef G_OS_UNIX
-      ep = g_io_extension_point_register (G_DESKTOP_APP_INFO_LOOKUP_EXTENSION_POINT_NAME);
-      g_io_extension_point_set_required_type (ep, G_TYPE_DESKTOP_APP_INFO_LOOKUP);
-#endif
-      
       ep = g_io_extension_point_register (G_LOCAL_DIRECTORY_MONITOR_EXTENSION_POINT_NAME);
       g_io_extension_point_set_required_type (ep, G_TYPE_LOCAL_DIRECTORY_MONITOR);
       
@@ -763,7 +759,7 @@ g_io_extension_point_get_extensions (GIOExtensionPoint *extension_point)
  *
  * Finds a #GIOExtension for an extension point by name.
  *
- * Returns: the #GIOExtension for @extension_point that has the
+ * Returns: (transfer none): the #GIOExtension for @extension_point that has the
  *    given name, or %NULL if there is no extension with that name
  */
 GIOExtension *
@@ -871,7 +867,7 @@ g_io_extension_point_implement (const char *extension_point_name,
  * Gets a reference to the class for the type that is 
  * associated with @extension.
  *
- * Returns: the #GTypeClass for the type of @extension
+ * Returns: (transfer full): the #GTypeClass for the type of @extension
  */
 GTypeClass *
 g_io_extension_ref_class (GIOExtension *extension)
