@@ -21,17 +21,20 @@
 
 #include "config.h"
 
-#include "glib.h"
-#include "glibintl.h"
-
 #include <string.h>
 
-#include "galias.h"
+#include "ghostutils.h"
+
+#include "garray.h"
+#include "gmem.h"
+#include "gstring.h"
+#include "gstrfuncs.h"
+#include "glibintl.h"
+
 
 /**
  * SECTION:ghostutils
  * @short_description: Internet hostname utilities
- * @include: glib.h
  *
  * Functions for manipulating internet hostnames; in particular, for
  * converting between Unicode and ASCII-encoded forms of
@@ -344,6 +347,9 @@ nameprep (const gchar *hostname,
   g_free (tmp);
   tmp = name;
 
+  if (!name)
+    return NULL;
+
   /* KC normalization may have created more capital letters (eg,
    * angstrom -> capital A with ring). So we have to lowercasify a
    * second time. (This is more-or-less how the nameprep algorithm
@@ -398,8 +404,11 @@ g_hostname_to_ascii (const gchar *hostname)
   gssize llen, oldlen;
   gboolean unicode;
 
-  out = g_string_new (NULL);
   label = name = nameprep (hostname, -1);
+  if (!name)
+    return NULL;
+
+  out = g_string_new (NULL);
 
   do
     {
@@ -591,6 +600,11 @@ g_hostname_to_unicode (const gchar *hostname)
         {
           gchar *canonicalized = nameprep (hostname, llen);
 
+          if (!canonicalized)
+            {
+              g_string_free (out, TRUE);
+              return NULL;
+            }
           g_string_append (out, canonicalized);
           g_free (canonicalized);
         }
@@ -753,6 +767,3 @@ g_hostname_is_ip_address (const gchar *hostname)
   /* If there's nothing left to parse, then it's ok. */
   return !*p;
 }
-
-#define __G_HOST_UTILS_C__
-#include "galiasdef.c"
